==> cdktf-cdktf-provider-google_beta-3.0.1.tar.gz: package/lib/data-google-access-approval-organization-service-account/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleAccessApprovalOrganizationServiceAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_access_approval_organization_service_account#id DataGoogleAccessApprovalOrganizationServiceAccount#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_access_approval_organization_service_account#organization_id DataGoogleAccessApprovalOrganizationServiceAccount#organization_id}
    */
    readonly organizationId: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/d/google_access_approval_organization_service_account google_access_approval_organization_service_account}
*/
export declare class DataGoogleAccessApprovalOrganizationServiceAccount extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_access_approval_organization_service_account";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/d/google_access_approval_organization_service_account google_access_approval_organization_service_account} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleAccessApprovalOrganizationServiceAccountConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleAccessApprovalOrganizationServiceAccountConfig);
    get accountEmail(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _organizationId?;
    get organizationId(): string;
    set organizationId(value: string);
    get organizationIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google_beta-7.0.0.tar.gz: package/lib/data-google-access-approval-organization-service-account/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleAccessApprovalOrganizationServiceAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_access_approval_organization_service_account#id DataGoogleAccessApprovalOrganizationServiceAccount#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_access_approval_organization_service_account#organization_id DataGoogleAccessApprovalOrganizationServiceAccount#organization_id}
    */
    readonly organizationId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_access_approval_organization_service_account google_access_approval_organization_service_account}
*/
export declare class DataGoogleAccessApprovalOrganizationServiceAccount extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "google_access_approval_organization_service_account";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_access_approval_organization_service_account google_access_approval_organization_service_account} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleAccessApprovalOrganizationServiceAccountConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleAccessApprovalOrganizationServiceAccountConfig);
    get accountEmail(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _organizationId?;
    get organizationId(): string;
    set organizationId(value: string);
    get organizationIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
